From 5c27ee115383d257d8d4f2280ad200e40dc36ceb Mon Sep 17 00:00:00 2001
From: Masahiko Sawada <sawada.mshk@gmail.com>
Date: Thu, 19 Jan 2023 23:29:16 +0900
Subject: [PATCH v20 07/13] Fix RT_DEBUG functions.

---
 src/include/lib/radixtree.h | 30 +++++++++++++++++-------------
 1 file changed, 17 insertions(+), 13 deletions(-)

diff --git a/src/include/lib/radixtree.h b/src/include/lib/radixtree.h
index 5bdfa74f72..b9e09f5761 100644
--- a/src/include/lib/radixtree.h
+++ b/src/include/lib/radixtree.h
@@ -115,9 +115,12 @@
 #define RT_DELETE RT_MAKE_NAME(delete)
 #endif
 #define RT_MEMORY_USAGE RT_MAKE_NAME(memory_usage)
+#ifdef RT_DEBUG
 #define RT_DUMP RT_MAKE_NAME(dump)
+#define RT_DUMP_NODE RT_MAKE_NAME(dump_node)
 #define RT_DUMP_SEARCH RT_MAKE_NAME(dump_search)
 #define RT_STATS RT_MAKE_NAME(stats)
+#endif
 
 /* internal helper functions (no externally visible prototypes) */
 #define RT_NEW_ROOT RT_MAKE_NAME(new_root)
@@ -1876,8 +1879,8 @@ RT_VERIFY_NODE(RT_PTR_LOCAL node)
 
 /***************** DEBUG FUNCTIONS *****************/
 #ifdef RT_DEBUG
-void
-rt_stats(RT_RADIX_TREE *tree)
+RT_SCOPE void
+RT_STATS(RT_RADIX_TREE *tree)
 {
 	ereport(NOTICE, (errmsg("num_keys = " UINT64_FORMAT ", height = %d, n4 = %u, n15 = %u, n32 = %u, n125 = %u, n256 = %u",
 						 tree->ctl->num_keys,
@@ -1890,7 +1893,7 @@ rt_stats(RT_RADIX_TREE *tree)
 }
 
 static void
-rt_dump_node(RT_PTR_LOCAL node, int level, bool recurse)
+RT_DUMP_NODE(RT_PTR_LOCAL node, int level, bool recurse)
 {
 	char		space[125] = {0};
 
@@ -1926,7 +1929,7 @@ rt_dump_node(RT_PTR_LOCAL node, int level, bool recurse)
 								space, n4->base.chunks[i]);
 
 						if (recurse)
-							rt_dump_node(n4->children[i], level + 1, recurse);
+							RT_DUMP_NODE(n4->children[i], level + 1, recurse);
 						else
 							fprintf(stderr, "\n");
 					}
@@ -1953,7 +1956,7 @@ rt_dump_node(RT_PTR_LOCAL node, int level, bool recurse)
 
 						if (recurse)
 						{
-							rt_dump_node(n32->children[i], level + 1, recurse);
+							RT_DUMP_NODE(n32->children[i], level + 1, recurse);
 						}
 						else
 							fprintf(stderr, "\n");
@@ -2005,7 +2008,7 @@ rt_dump_node(RT_PTR_LOCAL node, int level, bool recurse)
 								space, i);
 
 						if (recurse)
-							rt_dump_node(RT_NODE_INNER_125_GET_CHILD(n125, i),
+							RT_DUMP_NODE(RT_NODE_INNER_125_GET_CHILD(n125, i),
 										 level + 1, recurse);
 						else
 							fprintf(stderr, "\n");
@@ -2038,7 +2041,7 @@ rt_dump_node(RT_PTR_LOCAL node, int level, bool recurse)
 								space, i);
 
 						if (recurse)
-							rt_dump_node(RT_NODE_INNER_256_GET_CHILD(n256, i), level + 1,
+							RT_DUMP_NODE(RT_NODE_INNER_256_GET_CHILD(n256, i), level + 1,
 										 recurse);
 						else
 							fprintf(stderr, "\n");
@@ -2049,8 +2052,8 @@ rt_dump_node(RT_PTR_LOCAL node, int level, bool recurse)
 	}
 }
 
-void
-rt_dump_search(RT_RADIX_TREE *tree, uint64 key)
+RT_SCOPE void
+RT_DUMP_SEARCH(RT_RADIX_TREE *tree, uint64 key)
 {
 	RT_PTR_LOCAL node;
 	int			shift;
@@ -2079,7 +2082,7 @@ rt_dump_search(RT_RADIX_TREE *tree, uint64 key)
 	{
 		RT_PTR_LOCAL child;
 
-		rt_dump_node(node, level, false);
+		RT_DUMP_NODE(node, level, false);
 
 		if (NODE_IS_LEAF(node))
 		{
@@ -2100,8 +2103,8 @@ rt_dump_search(RT_RADIX_TREE *tree, uint64 key)
 	}
 }
 
-void
-rt_dump(RT_RADIX_TREE *tree)
+RT_SCOPE void
+RT_DUMP(RT_RADIX_TREE *tree)
 {
 
 	for (int i = 0; i < RT_SIZE_CLASS_COUNT; i++)
@@ -2119,7 +2122,7 @@ rt_dump(RT_RADIX_TREE *tree)
 		return;
 	}
 
-	rt_dump_node(tree->ctl->root, 0, true);
+	RT_DUMP_NODE(tree->ctl->root, 0, true);
 }
 #endif
 
@@ -2185,6 +2188,7 @@ rt_dump(RT_RADIX_TREE *tree)
 #undef RT_DELETE
 #undef RT_MEMORY_USAGE
 #undef RT_DUMP
+#undef RT_DUMP_NODE
 #undef RT_DUMP_SEARCH
 #undef RT_STATS
 
-- 
2.31.1

